close all
clear all
clc

% Euclidean method function examples.
%
% Input Parameters: dstarfun(x1,x2,x3,method)
%      - x1: biomarker scores for group 1. Must be column or row vector.
%      - x2: biomarker scores for group 2. Must be column or row vector.
%      - x3: biomarker scores for group 3. Must be column or row vector.
%      - method: determines which approach to use to estimate and
%                construct confidence intervals. Included are:
%                - 'normal': assumes normally distributed biomarker
%                            scores.
%                - 'boxbox': assumes biomarker scores can be transformed
%                            to approximate normality.
%                - 'kernel': nonparametric method when biomarker scores
%                            can not be transformed to approximate
%                            normality.
%      - plot: 'yes' for plot.
%              'none or blank for no plot.
% Output includes:
%      - D*, upper and lower bounds for D* CI.
%      - c1*, upper and lower bounds for c1* CI.
%      - c2*, upper and lower bounds for c2* CI.
%      - point estimates for TCR1, TCR2, and TCR3.

% 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                   Normal Scenario                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
rng(525232)

x1 = normrnd(5,1,1,100);
x2 = normrnd(5.5,1,1,80);
x3 = normrnd(6.3,1.2,1,50);

[dstar, c1, c2, tcrs] = dstar(x1,x2,x3,'normal','yes')


%%
close all
clear all
clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                  Box-Cox Scenario                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

x1 = gamrnd(1.1,1.5,1,100);
x2 = gamrnd(2,1.215,1,80);
x3 = gamrnd(1.65,2.7,1,50);

[dstar, c1, c2, tcrs] = dstar(x1,x2,x3,'boxcox','none')







%%
close all
clear all
clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                   Kernel Scenario                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



x1 = normrnd(1.8,1.66,1,100);
x2 = gamrnd(6,.6,1,100);
x3 = [normrnd(4.2,1.5,1,50), normrnd(9.2,1.5,1,35)]; 

[dstar, c1, c2, tcrs] = dstar(x1,x2,x3,'kernel')





